@@ -13,7 +13,7 @@
 										"\n",
 										"\n", "  Version",  vers, "\n\n",
 										"  GitHub: https://github.com/leandroroser/EcoGenetics-devel", "\n\n",
-										"  Online tutorial: https://github.com/leandroroser/EcoGenetics-Tutorial", "\n\n",
+										"  Online tutorial: https://leandroroser.github.io/EcoGenetics-Tutorial", "\n\n",
 										"  Overview: help('EcoGenetics')")
 	
 	packageStartupMessage(textstart)
